import React, { useState, useEffect } from 'react'
import { Select, Spin, Table, Button, Form, Input } from 'antd'
import NavLink from 'umi/navlink'
import { fetchList, apis } from '@/utils/request'
import Search from '../components/Search'
import List from '../components/List'


const Condition = props => {
  return (
    <Search
      onSearch={props.onSearch}
      onReset={props.onReset}
      render={form => {
        const { getFieldDecorator, setFieldsValue } = form
        
        return (
          <>
            <Form.Item label="公告编号">
            {
              getFieldDecorator('announcementNumber')(<Input placeholder="公告编号" />)
            }
            </Form.Item>
            <Form.Item label="公告标题">
            {
              getFieldDecorator('announcementTitle')(<Input placeholder="公告标题" />)
            }
            </Form.Item>
          </>
        )
      }}
    />
  )
}

const StatusDict = {
  '0': '已作废',
  '1': '已发布',
  '2': '草稿'
}

export default props => {
  const [loading, setLoading] = useState(false)
  const [listData, setListData] = useState([])

  const handleSearch = () => {

  }

  const handleDeleteRow = row => {

  }

  const handlePageChange = (pageNum, pageSize) => {

  }

  return (
    <div>
      <Condition onSearch={handleSearch} onReset={handleSearch} />
      <div style={{ margin: '24px 0' }}>
        <NavLink to={`/xxx`}>
          <Button type="primary">添加</Button>
        </NavLink>
        <Button style={{ marginLeft: '24px' }}>修改</Button>
        <Button type="danger" style={{ marginLeft: '24px' }}>修改</Button>
      </div>
      <Spin spinning={loading}>
        <List dataSource={listData} onPageChange={handlePageChange} rowKey="id">
          <Table.Column title="编号" dataIndex="id" key="id" />
          <Table.Column
            title="标题"
            dataIndex="announcementTitle"
            key="announcementTitle"
            render={(_, row) => {
              return (
                <NavLink to={`/xxx?id=${row.id}`}>
                  <Button type="link">{row.announcementTitle}</Button>
                </NavLink>
              )
            }}
          />
          <Table.Column title="查看数量" dataIndex="viewCount" key="viewCount" />
          <Table.Column
            title="状态"
            dataIndex="status"
            key="status"
            render={(_, row) => {
              if (row.status === '1' && (row.updateDate > row.createDate)) {
                return '已修改'
              }

              return StatusDict[row.status]
            }}
          />
          <Table.Column title="身份" dataIndex="roleName" key="roleName" />
          <Table.Column
            title="审核状态"
            dataIndex="verifyStatus"
            key="verifyStatus"
            render={(_, row) => {
              return (
                <span>
                  {verifyStatusDict[row.verifyStatus] || ''}
                </span>
              )
            }}
          />
          <Table.Column title="编辑人" dataIndex="updateName" key="updateName" />
          <Table.Column title="编辑时间" dataIndex="createDate" key="createDate" />
          <Table.Column
            title="操作"
            key="action"
            render={(_, row) => {
              return (
                <Popconfirm
                  title="确认进行删除操作?"
                  onConfirm={() => handleDeleteRow(row)}
                  okText="删除"
                  cancelText="取消"
                >
                  <Button type="link">删除</Button>
                </Popconfirm>
              )
            }}
          />
        </List>
      </Spin>

    </div>
  )
}
